==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/SeriesViewerManipulationEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var SeriesViewerManipulationEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SeriesViewerManipulationEventArgsDescription, _super);
    function SeriesViewerManipulationEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.g = false;
        _this.f = false;
        return _this;
    }
    SeriesViewerManipulationEventArgsDescription.prototype.get_type = function () {
        return "SeriesViewerManipulationEventArgs";
    };
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "isZoomPan", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("IsZoomPan");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "isDragZoom", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("IsDragZoom");
        },
        enumerable: true,
        configurable: true
    });
    SeriesViewerManipulationEventArgsDescription.$t = markType(SeriesViewerManipulationEventArgsDescription, 'SeriesViewerManipulationEventArgsDescription', Description.$);
    return SeriesViewerManipulationEventArgsDescription;
}(Description));
export { SeriesViewerManipulationEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SeriesViewerManipulationEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var SeriesViewerManipulationEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesViewerManipulationEventArgsDescription, _super);
    function SeriesViewerManipulationEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.j = false;
        _this.i = false;
        _this.h = false;
        return _this;
    }
    SeriesViewerManipulationEventArgsDescription.prototype.get_type = function () {
        return "SeriesViewerManipulationEventArgs";
    };
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "isZoomPan", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("IsZoomPan");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "isDragZoom", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("IsDragZoom");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SeriesViewerManipulationEventArgsDescription.prototype, "isDragSelect", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("IsDragSelect");
        },
        enumerable: false,
        configurable: true
    });
    SeriesViewerManipulationEventArgsDescription.$t = markType(SeriesViewerManipulationEventArgsDescription, 'SeriesViewerManipulationEventArgsDescription', Description.$);
    return SeriesViewerManipulationEventArgsDescription;
}(Description));
export { SeriesViewerManipulationEventArgsDescription };
